'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _keys = require('babel-runtime/core-js/object/keys');

var _keys2 = _interopRequireDefault(_keys);

var _getPrototypeOf = require('babel-runtime/core-js/object/get-prototype-of');

var _getPrototypeOf2 = _interopRequireDefault(_getPrototypeOf);

var _classCallCheck2 = require('babel-runtime/helpers/classCallCheck');

var _classCallCheck3 = _interopRequireDefault(_classCallCheck2);

var _createClass2 = require('babel-runtime/helpers/createClass');

var _createClass3 = _interopRequireDefault(_createClass2);

var _possibleConstructorReturn2 = require('babel-runtime/helpers/possibleConstructorReturn');

var _possibleConstructorReturn3 = _interopRequireDefault(_possibleConstructorReturn2);

var _inherits2 = require('babel-runtime/helpers/inherits');

var _inherits3 = _interopRequireDefault(_inherits2);

var _querystring = require('querystring');

var _querystring2 = _interopRequireDefault(_querystring);

var _Request2 = require('./Request');

var _Request3 = _interopRequireDefault(_Request2);

var _searchSpecV = require('./searchSpecV3');

var _lodash = require('lodash');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/**
 * YouTube search request
 * @type {SearchRequest}
 */
var SearchRequest = function (_Request) {
  (0, _inherits3.default)(SearchRequest, _Request);

  function SearchRequest() {
    (0, _classCallCheck3.default)(this, SearchRequest);
    return (0, _possibleConstructorReturn3.default)(this, (SearchRequest.__proto__ || (0, _getPrototypeOf2.default)(SearchRequest)).apply(this, arguments));
  }

  (0, _createClass3.default)(SearchRequest, [{
    key: 'isValidQueryParameters',

    /**
     * Validate query parameter names and values where feasible
     * @param  {Object}  query Object representing query name value pairs
     * @return {Boolean}       Whether or not the query parameters are valid
     */
    value: function isValidQueryParameters(query) {
      var result = true,
          params = this.specs.parameters,
          index = void 0;
      var keys = (0, _keys2.default)(query),
          length = keys.length;

      if (length === 0) return false;

      for (index = 0; index < length; ++index) {

        var key = keys[index];
        var param = (0, _lodash.find)(params, { 'name': key });

        if (typeof param === 'undefined') {
          result = false;
          throw new Error('Invalid query parameter name specified: ' + key);
        } else if (Array.isArray(param.values) && param.values.length > 0) {

          // @todo validate fields comma delimited parameter values
          // @todo validate publishedAfter/publishedBefore date values with regular expressions
          // @todo validate location values with regex. example 37.42307,-122.08427
          // @todo validate locationRadius values with regex. example 15m, 5km, 10ft, and 0.7mi
          // @todo validate regionCode values
          // @todo validate relevanceLanguage values

          if ((typeof param.values[0] === 'string' || typeof param.values[0] === 'number') && !(0, _lodash.includes)(param.values, query[key])) {
            result = false;
            throw new Error('Invalid query parameter value for ' + key + ' specified: ' + query[key]);
          } else if (typeof param.values[0] !== 'string' && typeof param.values[0] !== 'number') {

            var value = (0, _lodash.find)(param.values, { 'value': query[key] });
            if (typeof value === 'undefined') {
              result = false;
              throw new Error('Invalid query parameter value for ' + key + ' specified: ' + query[key]);
            }
          }
        }
      }
      return result;
    }
    /**
     * Getter for parameters.
     * @return {Object} Headers and query request parameters
     */

  }, {
    key: 'method',

    /**
     * Getter for method. Provide default HTTP method from specs.
     * @return {String} HTTP method: GET, POST...
     */
    get: function get() {
      if (typeof this._method === 'undefined') {
        this._method = this.specs.method;
      }
      return this._method;
    }
    /**
     * Setter for HTTP method.
     * @param  {String} method HTTP method
     */
    ,
    set: function set(method) {
      this._method = method;
    }
    /**
     * Getter for URL to make HTTP requests
     * @return {String} URL
     */

  }, {
    key: 'url',
    get: function get() {
      if (typeof this._url === 'undefined') {
        this._url = '' + this.specs.uri + this.query;
      }
      return this._url;
    }
    /**
     * Setter for URL to make HTTP requests
     * @param  {String} url URL
     */
    ,
    set: function set(url) {
      this._url = url;
    }
    /**
     * Build query string
     * @return {String} Query string
     */

  }, {
    key: 'query',
    get: function get() {
      var p = this.queryParameters;
      var q = _querystring2.default.stringify(p);
      return '' + this.specs.query + q;
    }
  }, {
    key: 'parameters',
    get: function get() {
      return this._parameters;
    }
    /**
     * Setter for parameters.
     * @param  {Object} parameters Headers and query request parameters
     */
    ,
    set: function set(parameters) {
      if (typeof parameters.query !== 'undefined' && this.isValidQueryParameters(parameters.query)) {
        this.queryParameters = parameters.query;
      }
      this._parameters = parameters;
    }
    /**
     * Getter for Container of query parameters
     * @return {Object} Container of query parameters
     */

  }, {
    key: 'queryParameters',
    get: function get() {
      if (typeof this._queryParameters === 'undefined') {
        this._queryParameters = {
          part: 'snippet'
        };
      }
      return this._queryParameters;
    }
    /**
     * Setter for container of query parameters
     * @param  {Object} queryParameters Container of query parameters
     */
    ,
    set: function set(queryParameters) {
      var _this2 = this;

      this.queryParameters;
      (0, _keys2.default)(queryParameters).forEach(function (key) {
        _this2._queryParameters[key] = queryParameters[key];
      });
    }
    /**
     * Getter for YouTube Search API specification
     * @return {Object} YouTube Search API specification
     */

  }, {
    key: 'specs',
    get: function get() {
      if (typeof this._specs === 'undefined') {
        this._specs = _searchSpecV.searchSpec;
      }
      return this._specs;
    }
    /**
     * Setter for YouTube Search API specification
     * @param  {Object} specs YouTube Search API specification
     */
    ,
    set: function set(specs) {
      this._specs = specs;
    }
  }]);
  return SearchRequest;
}(_Request3.default);

exports.default = SearchRequest;